@@ -1,6 +1,6 @@
 DATA_DIR = "/usr/local/share"
 PKG_DATA_DIR = "/usr/local/share/gnome-tweak-tool"
 GSETTINGS_SCHEMA_DIR = "/usr/local/share/glib-2.0/schemas"
-TWEAK_DIR = "/usr/local/lib/python2.7/site-packages/gtweak/tweaks"
-VERSION = "3.8.0"
+TWEAK_DIR = "/usr/local/lib/python2.7/dist-packages/gtweak/tweaks"
+VERSION = "3.8.1"
 LOCALE_DIR = "/usr/local/share/locale"
